RegionStatistic

Struct RegionStatistic 

pub struct RegionStatistic {
    pub num_rows: u64,
    pub memtable_size: u64,
    pub wal_size: u64,
    pub manifest_size: u64,
    pub sst_size: u64,
    pub sst_num: u64,
    pub index_size: u64,
    pub manifest: RegionManifestInfo,
    pub written_bytes: u64,
    pub data_topic_latest_entry_id: u64,
    pub metadata_topic_latest_entry_id: u64,
}
Represents the statistics of a region.

Fields

num_rows: u64

The number of rows stored in SST files owned by this region plus rows in memtables.

Rows from SST files referenced from other regions, for example after repartition, are not counted to avoid table-level double counting when summing region statistics.

memtable_size: u64

The size of memtable in bytes.

wal_size: u64

The size of WAL in bytes.

manifest_size: u64

The size of manifest in bytes.

sst_size: u64

The size of SST data files owned by this region in bytes.

SST files referenced from other regions, for example after repartition, are not counted.

sst_num: u64

The number of SST files owned by this region.

SST files referenced from other regions, for example after repartition, are not counted.

index_size: u64

The size of SST index files owned by this region in bytes.

SST index files referenced from other regions, for example after repartition, are not counted.

manifest: RegionManifestInfo

The details of the region.

written_bytes: u64

The total bytes written of the region since region opened.

data_topic_latest_entry_id: u64

The latest entry id of the region’s remote WAL since last flush. For metric engine, there’re two latest entry ids, one for data and one for metadata. TODO(weny): remove this two fields and use single instead.

metadata_topic_latest_entry_id: u64

Implementations

Source

impl RegionStatistic

pub fn deserialize_from_slice(value: &[u8]) -> Option<RegionStatistic>

Deserializes the region statistic to a byte array.

Returns None if the deserialization fails.

pub fn serialize_to_vec(&self) -> Option<Vec<u8>>

Serializes the region statistic to a byte array.

Returns None if the serialization fails.

Source

impl RegionStatistic

pub fn estimated_disk_size(&self) -> u64

Returns the estimated disk size of the region.