pub struct RegionStatistic {
pub num_rows: u64,
pub memtable_size: u64,
pub wal_size: u64,
pub manifest_size: u64,
pub sst_size: u64,
pub sst_num: u64,
pub index_size: u64,
pub manifest: RegionManifestInfo,
pub written_bytes: u64,
pub data_topic_latest_entry_id: u64,
pub metadata_topic_latest_entry_id: u64,
}Expand description
Represents the statistics of a region.
Fields
num_rows: u64The number of rows
memtable_size: u64The size of memtable in bytes.
wal_size: u64The size of WAL in bytes.
manifest_size: u64The size of manifest in bytes.
sst_size: u64The size of SST data files in bytes.
sst_num: u64The num of SST files.
index_size: u64The size of SST index files in bytes.
manifest: RegionManifestInfoThe details of the region.
written_bytes: u64The total bytes written of the region since region opened.
data_topic_latest_entry_id: u64The latest entry id of the region’s remote WAL since last flush. For metric engine, there’re two latest entry ids, one for data and one for metadata. TODO(weny): remove this two fields and use single instead.
metadata_topic_latest_entry_id: u64Implementations
Sourceimpl RegionStatistic
impl RegionStatistic
Sourcepub fn deserialize_from_slice(value: &[u8]) -> Option<RegionStatistic>
pub fn deserialize_from_slice(value: &[u8]) -> Option<RegionStatistic>
Deserializes the region statistic to a byte array.
Returns None if the deserialization fails.
Sourcepub fn serialize_to_vec(&self) -> Option<Vec<u8>>
pub fn serialize_to_vec(&self) -> Option<Vec<u8>>
Serializes the region statistic to a byte array.
Returns None if the serialization fails.
Sourceimpl RegionStatistic
impl RegionStatistic
Sourcepub fn estimated_disk_size(&self) -> u64
pub fn estimated_disk_size(&self) -> u64
Returns the estimated disk size of the region.